@@ -25,8 +25,8 @@ endpoint_name = None
               reraise=True)
 @log_on_end(logging.INFO, "Downloading {input_path:s} finished successfully")
 def load_csv(input_path):
-    # with download_file_from_s3(input_path) as csvfile:
-    with open(input_path, newline='') as csvfile:
+    with download_file_from_s3(input_path) as csvfile:
+    # with open(input_path, newline='') as csvfile:
         input_reader = csv.DictReader(csvfile, delimiter=',')
         rows = [row for row in input_reader]
         return rows
@@ -98,9 +98,9 @@ def write_to_s3(csv_content, bucket_name, file_path):
               reraise=True)
 @log_on_end(logging.INFO, "Writing {output_path:s} finished successfully")
 def write_output(output: List[Dict], output_path):
-    # bucket_name, file_path = parse_s3_url(output_path)
-    # with io.StringIO() as csvfile:
-    with open(output_path, 'w', newline='') as csvfile:
+    bucket_name, file_path = parse_s3_url(output_path)
+    with io.StringIO() as csvfile:
+    # with open(output_path, 'w', newline='') as csvfile:
         fieldnames = list(output[0].keys())
         writer = csv.DictWriter(csvfile, fieldnames=fieldnames, quotechar='"')
 
@@ -108,9 +108,9 @@ def write_output(output: List[Dict], output_path):
         for row in output:
             writer.writerow(row)
 
-        #csv_content = bytes(csvfile.getvalue(), encoding='utf-8')
+        csv_content = bytes(csvfile.getvalue(), encoding='utf-8')
 
-        #write_to_s3(csv_content, bucket_name, file_path)
+        write_to_s3(csv_content, bucket_name, file_path)
 
 
 def main(input_path: str, output_path: str):
